paidiverpy.models.config_model
==============================

.. py:module:: paidiverpy.models.config_model

.. autoapi-nested-parse::

   Configuration model for Paidiverpy.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.config_model.ConfigModel


Module Contents
---------------

.. py:class:: ConfigModel(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Step configuration model.
















   ..
       !! processed by numpydoc !!

